.. index:: ! data store; main

Data Stores
===========

A :term:`data store` is how Karaage updates external databases, such a LDAP,
PBS, and Slurm.

Contents:

.. toctree::
   :glob:

   datastores/*
